===============================
List Match
===============================


.. image:: https://img.shields.io/pypi/v/listmatch.svg
        :target: https://pypi.python.org/pypi/listmatch

.. image:: https://img.shields.io/travis/pokey/listmatch.svg
        :target: https://travis-ci.org/pokey/listmatch

.. image:: https://readthedocs.org/projects/listmatch/badge/?version=latest
        :target: https://listmatch.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/pokey/listmatch/shield.svg
     :target: https://pyup.io/repos/github/pokey/listmatch/
     :alt: Updates


Regexes for lists.


* Free software: MIT license
* Documentation: https://listmatch.readthedocs.io.


Features
--------

TODO


Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

The code was adapted from https://github.com/xysun/regex
